<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

if ( ! function_exists( 'pet_business_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Pet Business Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pet_business_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'pet_business_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pet_business_pro_is_nav_btn_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Pet Business Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pet_business_pro_is_nav_btn_enable( $control ) {
		return $control->manager->get_setting( 'pet_business_pro_theme_options[nav_btn]' )->value();
	}
endif;

if ( ! function_exists( 'pet_business_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Pet Business Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pet_business_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'pet_business_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pet_business_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Pet Business Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pet_business_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'pet_business_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[slider_content_type]' )->value();
	return pet_business_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_slider_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[slider_content_type]' )->value();
	return pet_business_pro_is_slider_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if slider section seperator.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_slider_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[slider_content_type]' )->value();
	return pet_business_pro_is_slider_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if slider section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[slider_content_type]' )->value();
	return pet_business_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[slider_content_type]' )->value();
	return pet_business_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if video section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[about_content_type]' )->value();
	return pet_business_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[about_content_type]' )->value();
	return pet_business_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[about_content_type]' )->value();
	return pet_business_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[service_content_type]' )->value();
	return pet_business_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[service_content_type]' )->value();
	return pet_business_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[service_content_type]' )->value();
	return pet_business_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[service_content_type]' )->value();
	return pet_business_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is tp-service-cat.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_service_section_content_service_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[service_content_type]' )->value();
	return pet_business_pro_is_service_section_enable( $control ) && ( 'tp-service-cat' == $content_type );
}

/**
 * Check if project section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[project_section_enable]' )->value() );
}

/**
 * Check if project section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_project_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[project_content_type]' )->value();
	return pet_business_pro_is_project_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if project section seperator.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_project_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[project_content_type]' )->value();
	return pet_business_pro_is_project_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if project section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_project_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[project_content_type]' )->value();
	return pet_business_pro_is_project_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if project section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_project_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[project_content_type]' )->value();
	return pet_business_pro_is_project_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if project section content type is tp-project-cat.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_project_section_content_project_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[project_content_type]' )->value();
	return pet_business_pro_is_project_section_enable( $control ) && ( 'tp-project-cat' == $content_type );
}

/**
 * Check if product section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[product_section_enable]' )->value() );
}

/**
 * Check if product section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[product_content_type]' )->value();
	return pet_business_pro_is_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if product section seperator.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[product_content_type]' )->value();
	return pet_business_pro_is_product_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if product section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[product_content_type]' )->value();
	return pet_business_pro_is_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if product section content type is product.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[product_content_type]' )->value();
	return pet_business_pro_is_product_section_enable( $control ) && ( 'woo-product' == $content_type );
}

/**
 * Check if product section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[product_content_type]' )->value();
	return pet_business_pro_is_product_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if product section content type is tp-product-cat.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[product_content_type]' )->value();
	return pet_business_pro_is_product_section_enable( $control ) && ( 'tp-product-cat' == $content_type );
}

/**
 * Check if pricing section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_pricing_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[pricing_section_enable]' )->value() );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[testimonial_content_type]' )->value();
	return pet_business_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[testimonial_content_type]' )->value();
	return pet_business_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[testimonial_content_type]' )->value();
	return pet_business_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[testimonial_content_type]' )->value();
	return pet_business_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Check if cta section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_enable_1( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[cta_section_enable_1]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_content_post_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[cta_content_type_1]' )->value();
	return pet_business_pro_is_cta_section_enable_1( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_content_page_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[cta_content_type_1]' )->value();
	return pet_business_pro_is_cta_section_enable_1( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_content_custom_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[cta_content_type_1]' )->value();
	return pet_business_pro_is_cta_section_enable_1( $control ) && ( 'custom' == $content_type );
}







/**
 * Check if cta section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_enable_2( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[cta_section_enable_2]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_content_post_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[cta_content_type_2]' )->value();
	return pet_business_pro_is_cta_section_enable_2( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_content_page_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[cta_content_type_2]' )->value();
	return pet_business_pro_is_cta_section_enable_2( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_cta_section_content_custom_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[cta_content_type_2]' )->value();
	return pet_business_pro_is_cta_section_enable_2( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[team_content_type]' )->value();
	return pet_business_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[team_content_type]' )->value();
	return pet_business_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[team_content_type]' )->value();
	return pet_business_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[team_content_type]' )->value();
	return pet_business_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[team_content_type]' )->value();
	return pet_business_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[blog_content_type]' )->value();
	return pet_business_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[blog_content_type]' )->value();
	return pet_business_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[blog_content_type]' )->value();
	return pet_business_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[blog_content_type]' )->value();
	return pet_business_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[contact_section_enable]' )->value() );
}

/**
 * Check if contact section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_contact_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[contact_content_type]' )->value();
	return pet_business_pro_is_contact_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if contact section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_contact_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[contact_content_type]' )->value();
	return pet_business_pro_is_contact_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if contact section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_contact_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[contact_content_type]' )->value();
	return pet_business_pro_is_contact_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if contact section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_client_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[client_section_enable]' )->value() );
}

/**
 * Check if popular post section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if popular_post section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[popular_post_content_type]' )->value();
	return pet_business_pro_is_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_post section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[popular_post_content_type]' )->value();
	return pet_business_pro_is_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_post section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[popular_post_content_type]' )->value();
	return pet_business_pro_is_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[topbar_section_enable]' )->value() );
}


/**
 * Check if reason section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_reason_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[reason_section_enable]' )->value() );
}

/**
 * Check if reason section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[reason_content_type]' )->value();
	return pet_business_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if reason section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[reason_content_type]' )->value();
	return pet_business_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is custom.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_reason_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[reason_content_type]' )->value();
	return pet_business_pro_is_reason_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if must section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_must_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[must_section_enable]' )->value() );
}

/**
 * Check if must section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_must_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[must_content_type]' )->value();
	return pet_business_pro_is_must_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if must section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_must_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[must_content_type]' )->value();
	return pet_business_pro_is_must_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if must section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_must_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[must_content_type]' )->value();
	return pet_business_pro_is_must_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if must section content type is recent.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_must_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[must_content_type]' )->value();
	return pet_business_pro_is_must_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if most section is enabled.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_most_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pet_business_pro_theme_options[most_section_enable]' )->value() );
}

/**
 * Check if most section content type is post.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_most_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[most_content_type]' )->value();
	return pet_business_pro_is_most_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most section content type is page.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_most_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[most_content_type]' )->value();
	return pet_business_pro_is_most_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most section content type is category.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_most_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[most_content_type]' )->value();
	return pet_business_pro_is_most_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most section content type is recent.
 *
 * @since Pet Business Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pet_business_pro_is_most_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pet_business_pro_theme_options[most_content_type]' )->value();
	return pet_business_pro_is_most_section_enable( $control ) && ( 'recent' == $content_type );
}
