<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'pet_business_pro_about_section', array(
	'title'             => esc_html__( 'About Us','pet-business-pro' ),
	'description'       => esc_html__( 'About Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_about_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'pet-business-pro' ),
		'post' 		=> esc_html__( 'Post', 'pet-business-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'pet-business-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_page',
) );

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_about_section',
	'choices'			=> pet_business_pro_page_choices(),
	'active_callback'	=> 'pet_business_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_page',
) );

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_about_section',
	'choices'			=> pet_business_pro_post_choices(),
	'active_callback'	=> 'pet_business_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_about_section',
	'active_callback' 	=> 'pet_business_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[about_title]', array(
		'selector'            => '#about-us h2.section-title',
		'settings'            => 'pet_business_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'pet-business-pro' ),
	'description'           	=> esc_html__( 'HTML allowed', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_about_section',
	'active_callback' 	=> 'pet_business_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .section-subtitle',
		'settings'            => 'pet_business_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_about_description_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' 			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_about_section',
	'active_callback' 	=> 'pet_business_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-us a.btn',
		'settings'            => 'pet_business_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_about_section',
	'active_callback' 	=> 'pet_business_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

if ( $options['home_layout'] == 'fourth-design' ):

// image setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pet_business_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'pet-business-pro' ),
		'section'     		=> 'pet_business_pro_about_section',
		'active_callback'	=> 'pet_business_pro_is_about_section_content_custom_enable',
) ) );

endif;


if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'third-design'  || $options['home_layout'] == 'fifth-design'):

// about note control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[about_heading_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[about_heading_label]', array(
	'label'             => esc_html__( 'Video section', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_about_section',
	'active_callback'	=> 'pet_business_pro_is_about_section_enable',
) ) );

// Video content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[video_section_enable]', array(
	'default'			=> 	$options['video_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[video_section_enable]', array(
	'label'             => esc_html__( 'Video Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_about_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// Video link setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[video_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[video_link]', array(
	'label'           	=> esc_html__( 'Video Link', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_about_section',
	'active_callback' 	=> 'pet_business_pro_is_video_section_enable',
	'type'				=> 'url',
) );

$wp_customize->add_setting( 'pet_business_pro_theme_options[ads_image]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pet_business_pro_theme_options[ads_image]',
		array(
		'label'       		=> esc_html__( 'Ads Image', 'pet-business-pro' ),
		'section'     		=> 'pet_business_pro_about_section',
) ) );

$wp_customize->add_setting( 'pet_business_pro_theme_options[ads_image_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[ads_image_url]', array(
	'label'           	=> esc_html__( 'Ads Image Link', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_about_section',
	'type'				=> 'url',
) );

endif;