<?php
/**
 * must Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add must section
$wp_customize->add_section( 'pet_business_pro_must_section', array(
	'title'             => esc_html__( 'Must Read','pet-business-pro' ),
	'description'       => esc_html__( 'Must Read Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// must content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_section_enable]', array(
	'default'			=> 	$options['must_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[must_section_enable]', array(
	'label'             => esc_html__( 'must Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// must note control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_heading_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[must_heading_label]', array(
	'label'             => esc_html__( 'Heading Section', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'active_callback'	=> 'pet_business_pro_is_must_section_enable',
) ) );


// must title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['must_title'],
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[must_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_must_section',
	'active_callback' 	=> 'pet_business_pro_is_must_section_enable',
	'type'				=> 'text',
) );


// must note control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_content_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[must_content_label]', array(
	'label'             => esc_html__( 'Content Section', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'active_callback'	=> 'pet_business_pro_is_must_section_enable',
) ) );

// must content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_column]', array(
	'default'          	=> $options['must_column'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[must_column]', array(
	'label'             => esc_html__( 'Column Layout', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_must_section_enable',
	'choices'			=> array( 
		'col-1' 	=> esc_html__( 'One Column', 'pet-business-pro' ),
		'col-2' 	=> esc_html__( 'Two Column', 'pet-business-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'pet-business-pro' ),
		'col-4' 	=> esc_html__( 'Four Column', 'pet-business-pro' ),
	),
) );

// must content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_content_type]', array(
	'default'          	=> $options['must_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[must_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_must_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'pet-business-pro' ),
		'post' 		=> esc_html__( 'Post', 'pet-business-pro' ),
		'category' 	=> esc_html__( 'Category', 'pet-business-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'pet-business-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_count]', array(
	'default'          	=> $options['must_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
	'validate_callback' => 'pet_business_pro_validate_must_count',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[must_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'active_callback'   => 'pet_business_pro_is_must_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['must_count']; $i++ ) :
	// must pages drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[must_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[must_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_must_section',
		'choices'			=> pet_business_pro_page_choices(),
		'active_callback'	=> 'pet_business_pro_is_must_section_content_page_enable',
	) ) );

	// must posts drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[must_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[must_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_must_section',
		'choices'			=> pet_business_pro_post_choices(),
		'active_callback'	=> 'pet_business_pro_is_must_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pet_business_pro_theme_options[must_content_category]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pet_business_pro_theme_options[must_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pet-business-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pet_business_pro_is_must_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[must_category_exclude]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Category_Control( $wp_customize,'pet_business_pro_theme_options[must_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'pet-business-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Ctrl key select multilple categories.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_must_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'pet_business_pro_is_must_section_content_recent_enable'
) ) );
