<?php
/**
 * Popular Post Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Popular section
$wp_customize->add_section( 'pet_business_pro_popular_post_section', array(
	'title'             => esc_html__( 'Popular Post','pet-business-pro' ),
	'description'       => esc_html__( 'Popular Post Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Popular content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_section_enable]', array(
	'default'			=> 	$options['popular_post_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[popular_post_section_enable]', array(
	'label'             => esc_html__( 'Popular Post Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_popular_post_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// popular title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_post_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[popular_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_popular_post_section',
	'active_callback' 	=> 'pet_business_pro_is_popular_post_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[popular_post_title]', array(
		'selector'            => '#blog-popular-posts .section-header h2.section-title',
		'settings'            => 'pet_business_pro_theme_options[popular_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_popular_post_title_partial',
    ) );
}


if ( $options['home_layout'] == 'third-design' ):

// popular button setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_description]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_post_description'],
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[popular_post_description]', array(
	'label'           	=> esc_html__( 'Short Description', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_popular_post_section',
	'active_callback' 	=> 'pet_business_pro_is_popular_post_section_enable',
	'type'				=> 'textarea',
) );

endif;

if ( $options['home_layout'] !== 'third-design' ):

// popular button setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_post_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[popular_post_button]', array(
	'label'           	=> esc_html__( 'Button', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_popular_post_section',
	'active_callback' 	=> 'pet_business_pro_is_popular_post_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[popular_post_button]', array(
		'selector'            => '#blog-popular-posts .wrapper div.read-more a',
		'settings'            => 'pet_business_pro_theme_options[popular_post_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_popular_post_button_partial',
    ) );
}
endif;

// popular number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_count]', array(
	'default'          	=> $options['popular_post_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
	'validate_callback' => 'pet_business_pro_validate_popular_post_count',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[popular_post_count]', array(
	'label'             => esc_html__( 'Number of Popular Post', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_popular_post_section',
	'active_callback'   => 'pet_business_pro_is_popular_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// Popular content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_content_type]', array(
	'default'          	=> $options['popular_post_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[popular_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_popular_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_popular_post_section_enable',
	'choices'			=> pet_business_pro_work_section_options(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pet_business_pro_theme_options[popular_post_content_category]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pet_business_pro_theme_options[popular_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pet-business-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_popular_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pet_business_pro_is_popular_post_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['popular_post_count']; $i++ ) :

	// Popular pages drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[popular_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_popular_post_section',
		'choices'			=> pet_business_pro_page_choices(),
		'active_callback'	=> 'pet_business_pro_is_popular_post_section_content_page_enable',
	) ) );

	// Popular posts drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[popular_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Popular Post %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_popular_post_section',
		'choices'			=> pet_business_pro_post_choices(),
		'active_callback'	=> 'pet_business_pro_is_popular_post_section_content_post_enable',
	) ) );

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[popular_post_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[popular_post_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_popular_post_section',
		'active_callback'	=> 'pet_business_pro_is_popular_post_section_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;

