<?php
/**
 * Project Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Project section
$wp_customize->add_section( 'pet_business_pro_project_section', array(
	'title'             => esc_html__( 'Project','pet-business-pro' ),
	'description'       => esc_html__( 'Project Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Project content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[project_section_enable]', array(
	'default'			=> 	$options['project_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[project_section_enable]', array(
	'label'             => esc_html__( 'Project Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_project_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

if ( $options['home_layout'] !== 'fourth-design' ):
// project title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[project_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['project_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[project_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_project_section',
	'active_callback' 	=> 'pet_business_pro_is_project_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[project_title]', array(
		'selector'            => '#latest-projects h2.section-title',
		'settings'            => 'pet_business_pro_theme_options[project_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_project_title_partial',
    ) );
}

endif;

if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' ):

// project sub title
$wp_customize->add_setting( 'pet_business_pro_theme_options[project_sub_title]', array(
	'default'          	=> $options['project_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[project_sub_title]', array(
	'label'             => esc_html__( 'Sub title', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_project_section',
	'active_callback'	=> 'pet_business_pro_is_project_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[project_sub_title]', array(
		'selector'            => '#latest-projects .section-subtitle',
		'settings'            => 'pet_business_pro_theme_options[project_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_project_sub_title_partial',
    ) );
}

endif;

// project number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[project_count]', array(
	'default'          	=> $options['project_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
	'validate_callback' => 'pet_business_pro_validate_project_count',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[project_count]', array(
	'label'             => esc_html__( 'Number of Project', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_project_section',
	'active_callback'   => 'pet_business_pro_is_project_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// Project content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[project_content_type]', array(
	'default'          	=> $options['project_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[project_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_project_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_project_section_enable',
	'choices'			=> pet_business_pro_work_section_options(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pet_business_pro_theme_options[project_content_category]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pet_business_pro_theme_options[project_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pet-business-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_project_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pet_business_pro_is_project_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['project_count']; $i++ ) :

	// project pages drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[project_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[project_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_project_section',
		'choices'			=> pet_business_pro_page_choices(),
		'active_callback'	=> 'pet_business_pro_is_project_section_content_page_enable',
	) ) );

	// project posts drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[project_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[project_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Project %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_project_section',
		'choices'			=> pet_business_pro_post_choices(),
		'active_callback'	=> 'pet_business_pro_is_project_section_content_post_enable',
	) ) );

	// project custom date
	$wp_customize->add_setting( 'pet_business_pro_theme_options[project_custom_meta_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[project_custom_meta_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Meta %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_project_section',
		'active_callback'	=> 'pet_business_pro_is_project_section_content_page_enable',
	) );

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[project_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[project_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_project_section',
		'active_callback'	=> 'pet_business_pro_is_project_section_content_page_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;

