<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'pet_business_pro_slider_section', array(
	'title'             => esc_html__( 'Sliders','pet-business-pro' ),
	'description'       => esc_html__( 'Sliders Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_slider_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// Slider content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'pet-business-pro' ),
		'post' 		=> esc_html__( 'Post', 'pet-business-pro' ),
		'category' 	=> esc_html__( 'Category', 'pet-business-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'pet-business-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
	'validate_callback' => 'pet_business_pro_validate_slider_count',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Sliders', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_slider_section',
	'active_callback'   => 'pet_business_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

if ( $options['home_layout'] == 'second-design' || $options['home_layout'] == 'fourth-design' ):
// slider blog button setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_blog_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_blog_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[slider_blog_button]', array(
	'label'           	=> esc_html__( 'Button Label', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_slider_section',
	'active_callback' 	=> 'pet_business_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[slider_blog_button]', array(
		'selector'            => '#featured-slider div.buttons a',
		'settings'            => 'pet_business_pro_theme_options[slider_blog_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_slider_blog_button_partial',
    ) );
}

endif;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pet_business_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pet_business_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pet-business-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pet_business_pro_is_slider_section_content_category_enable'
) ) );


for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_slider_section',
		'choices'			=> pet_business_pro_page_choices(),
		'active_callback'	=> 'pet_business_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_slider_section',
		'choices'			=> pet_business_pro_post_choices(),
		'active_callback'	=> 'pet_business_pro_is_slider_section_content_post_enable',
	) ) );

	// slider custom title
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_custom_title_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Title %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_slider_section',
		'active_callback'	=> 'pet_business_pro_is_slider_section_content_custom_enable',
	) );

	// slider custom content
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_content_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_custom_content_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Content %d', 'pet-business-pro' ), $i ),
		'description'             => esc_html__( 'HTML allowed.', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_slider_section',
		'type'				=> 'textarea',
		'active_callback'	=> 'pet_business_pro_is_slider_section_content_custom_enable',
	) );

	// slider image
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_image_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pet_business_pro_theme_options[slider_content_custom_image_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Image %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_slider_section',
		'active_callback'   => 'pet_business_pro_is_slider_section_content_custom_enable',
	) ) );

	if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design'):

	// slider custom button 1
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_btn_1_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_custom_btn_1_' . $i . ']', array(
		'label'             => esc_html__( 'Button One', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_slider_section',
		'type'				=> 'url',
		'active_callback'	=> 'pet_business_pro_is_slider_section_enable',
	) );

	// slider custom url 1
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_url_1_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_custom_url_1_' . $i . ']', array(
		'label'             => esc_html__( 'URL One', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_slider_section',
		'type'				=> 'url',
		'active_callback'	=> 'pet_business_pro_is_slider_section_enable',
	) );

	// slider custom button 2
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_btn_2_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_custom_btn_2_' . $i . ']', array(
		'label'             => esc_html__( 'Button Two', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_slider_section',
		'type'				=> 'url',
		'active_callback'	=> 'pet_business_pro_is_slider_section_enable',
	) );

	// slider custom url 2
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_content_custom_url_2_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[slider_content_custom_url_2_' . $i . ']', array(
		'label'             => esc_html__( 'URL Two', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_slider_section',
		'type'				=> 'url',
		'active_callback'	=> 'pet_business_pro_is_slider_section_enable',
	) );

	endif;

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[slider_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[slider_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_slider_section',
		'active_callback'	=> 'pet_business_pro_is_slider_section_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;