<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'pet_business_pro_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','pet-business-pro' ),
	'description'       => esc_html__( 'Archive section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_theme_options_panel',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'pet-business-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'pet_business_pro_is_latest_posts'
) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_archive_section',
	'on_off_label' 		=> pet_business_pro_hide_options(),
) ) );

// Archive author category setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[hide_category]', array(
	'default'           => $options['hide_category'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[hide_category]', array(
	'label'             => esc_html__( 'Hide Category', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_archive_section',
	'on_off_label' 		=> pet_business_pro_hide_options(),
) ) );


// Archive content column type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[archive_col]', array(
	'default'          	=> $options['archive_col'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[archive_col]', array(
	'label'             => esc_html__( 'Columns:', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'col-2' 		=> esc_html__( 'Columns 2', 'pet-business-pro' ),
		'col-3' 	=> esc_html__( 'Columns 3', 'pet-business-pro' ),
	),
) );
