<?php
/**
 * Menu options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'pet_business_pro_menu', array(
	'title'             => esc_html__('Header Menu','pet-business-pro'),
	'description'       => esc_html__( 'Header Menu options.', 'pet-business-pro' ),
	'panel'             => 'nav_menus',
) );

// Menu sticky setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[menu_sticky]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
	'default'           => $options['menu_sticky'],
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[menu_sticky]', array(
	'label'             => esc_html__( 'Make Menu Sticky', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_menu',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// search enable setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[nav_search_enable]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
	'default'           => $options['nav_search_enable'],
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[nav_search_enable]', array(
	'label'             => esc_html__( 'Enable search', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_menu',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// menu Layout control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[menu_style]', array(
	'default'          	=> $options['menu_style'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[menu_style]', array(
	'label'             => esc_html__( 'Menu Style', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_menu',
	'type'				=> 'select',
	'choices'			=> array( 
		'classic-menu' 		=> esc_html__( 'Classic Menu', 'pet-business-pro' ),
		'modern-menu' 		=> esc_html__( 'Modern Menu', 'pet-business-pro' ),
	),
) );

// menu Layout control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[menu_bg]', array(
	'default'          	=> $options['menu_bg'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
	'transport' => 'refresh',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[menu_bg]', array(
	'label'             => esc_html__( 'Menu Background', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_menu',
	'type'				=> 'select',
	'choices'			=> array( 
		'' 					=> esc_html__( 'Not Transparent', 'pet-business-pro' ),
		'absolute-header' 	=> esc_html__( 'Transparent', 'pet-business-pro' ),
	),
) );

$options = pet_business_pro_get_theme_options();
if ( $options['home_layout'] == 'default-design' ):

// button enable setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[nav_btn]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
	'default'           => $options['nav_btn'],
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[nav_btn]', array(
	'label'             => esc_html__( 'Enable button', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_menu',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// button text setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[nav_btn_txt]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['nav_btn_txt'],
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[nav_btn_txt]', array(
	'label'           	=> esc_html__( 'Button label', 'pet-business-pro' ),
	'active_callback' 	=> 'pet_business_pro_is_nav_btn_enable',
	'section'        	=> 'pet_business_pro_menu',
) );

// button url setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[nav_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> $options['nav_btn_url'],
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[nav_btn_url]', array(
	'label'           	=> esc_html__( 'Button url', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_menu',
	'active_callback' 	=> 'pet_business_pro_is_nav_btn_enable',
	'type'				=> 'url'
) );

endif;