<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_about_section() {
    	$options = pet_business_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'pet_business_pro_section_status', true, 'about_section_enable' );
        $video_enable = apply_filters( 'pet_business_pro_section_status', true, 'video_section_enable' );

        if ( ! $about_enable && ! $video_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'pet_business_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        pet_business_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'pet_business_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Pet Business Pro 1.0.0
    * @param array $input about section details.
    */
    function pet_business_pro_get_about_section_details( $input ) {
        $options = pet_business_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '#';
                $custom['image']        =  ! empty( $options['about_image'] ) ? $options['about_image'] : '#' ; 

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = pet_business_pro_trim_content( 50 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'pet_business_pro_filter_about_section_details', 'pet_business_pro_get_about_section_details' );


if ( ! function_exists( 'pet_business_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_about_section( $content_details = array() ) {

        $options = pet_business_pro_get_theme_options();
        $about_content_type  = $options['about_content_type'];
        $featured_video = ! empty( $options['video_link'] ) ? $options['video_link'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="pet_business_pro_about_section">

        <?php

        if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' ):

        foreach ( $content_details as $content ) : 
            ?>
            <div id="about-us" class="relative page-section">
                <?php if ( $options['about_section_enable'] ) : ?>
                    <div class="wrapper">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            <?php if ( ( 'page' == $about_content_type ) || ( 'post' == $about_content_type ) ) { ?>
                                    <p class="section-subtitle"><?php echo esc_html( $content['excerpt'] ); ?></p>
                            <?php } else { ?>
                                    <p class="section-subtitle"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            <?php } ?>

                        </div><!-- .section-header -->

                        <?php if ( ! empty( $options['about_btn_title'] ) ) : ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $options['about_btn_title'] ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .wrapper -->
                <?php endif; ?>

                <?php if ( $options['video_section_enable'] ) : 
                    if ( ! empty( $featured_video ) ) : 
                        $library_video =  attachment_url_to_postid( $featured_video );
                    ?>
                    <div class="wrapper">
                        <div class="video-wrapper">
                            <?php
                            if ( 0 !== $library_video ) :
                                the_widget( 'WP_Widget_Media_Video', $instance = array( 'attachment_id' => absint( $library_video ) ) ); 
                            else :
                                the_widget( 'WP_Widget_Media_Video', $instance = array( 'url' => esc_url( $featured_video ) ) ); 
                            endif;
                            ?>
                        </div><!-- .video-wrapper -->
                    </div><!-- .wrapper -->
                    <?php 
                    endif;

                endif; ?>
            </div><!-- #about-me -->
            <?php if ( $options['home_layout'] == 'fifth-design' && $options['ads_image'] !=='' ): ?>
                <div class="magazine-site-advertisement">
                    <div class="wrapper">
                        <a href="<?php echo esc_url( $options['ads_image_url'] ) ?>"><img src="<?php echo esc_url( $options['ads_image'] ) ?>" alt="site-advertisement-01"></a>
                    </div><!-- .wrapper -->
                </div>
            <?php endif ?>
        <?php endforeach;
        endif;

        if ( $options['home_layout'] == 'fourth-design' ):

            foreach ( $content_details as $content ) : ?>

            <div id="medical-about-us" class="relative page-section">
                <div class="wrapper">
                    <article class="has-post-thumbnail">
                    <?php if( !empty( $content['image'] ) ): ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                        <div class="entry-container">
                        <?php if( !empty( $content['title'] ) ): ?>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                        <?php endif; ?>

                            <?php if( !empty( $content['excerpt'] ) ): ?>
                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        <?php endif; ?>

                            <?php if ( ! empty( $options['about_btn_title'] ) ) : ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['about_btn_title'] ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div>

            <?php
            endforeach;

            endif;
            ?>
            </div>
            <?php
    }
endif;