<?php
/**
 * must section
 *
 * This is the template for the content of must section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_must_section' ) ) :
    /**
    * Add must section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_must_section() {
    	$options = pet_business_pro_get_theme_options();
        // Check if must is enabled on frontpage
        $must_enable = apply_filters( 'pet_business_pro_section_status', true, 'must_section_enable' );

        if ( true !== $must_enable ) {
            return false;
        }
        // Get must section details
        $section_details = array();
        $section_details = apply_filters( 'pet_business_pro_filter_must_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render must section now.
        pet_business_pro_render_must_section( $section_details );
    }
endif;

if ( ! function_exists( 'pet_business_pro_get_must_section_details' ) ) :
    /**
    * must section details.
    *
    * @since Pet Business Pro 1.0.0
    * @param array $input must section details.
    */
    function pet_business_pro_get_must_section_details( $input ) {
        $options = pet_business_pro_get_theme_options();

        // Content type.
        $must_content_type  = $options['must_content_type'];
        $must_count = ! empty( $options['must_count'] ) ? $options['must_count'] : 3;
        
        $content = array();
        switch ( $must_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $must_count; $i++ ) {
                    if ( ! empty( $options['must_content_page_' . $i] ) )
                        $page_ids[] = $options['must_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $must_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $must_count; $i++ ) {
                    if ( ! empty( $options['must_content_post_' . $i] ) )
                        $post_ids[] = $options['must_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $must_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['must_content_category'] ) ? $options['must_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $must_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['must_category_exclude'] ) ? $options['must_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $must_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['author_id'] = get_the_author_meta( 'ID' );
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = pet_business_pro_trim_content( 15 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// must section content details.
add_filter( 'pet_business_pro_filter_must_section_details', 'pet_business_pro_get_must_section_details' );


if ( ! function_exists( 'pet_business_pro_render_must_section' ) ) :
  /**
   * Start must section
   *
   * @return string must content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_must_section( $content_details = array() ) {
        $options = pet_business_pro_get_theme_options();
        $must_content_type  = $options['must_content_type'];
        $column = ! empty( $options['must_column'] ) ? $options['must_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="magazine-must-read" class="page-section">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['must_title'] ) ?></h2>
                </div><!-- .section-header -->

                <div class="section-content magazine <?php echo esc_attr( $column ) ?> clear">
                	<?php foreach ($content_details as $content): ?>
                		<article class="hentry">
	                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
	                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
	                        </div><!-- .featured-image -->

	                        <div class="entry-container">
	                            <header class="entry-header">
	                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
	                            </header>

	                            <div class="entry-meta">
	                                <?php pet_business_pro_posted_on( $content['id'] ); ?>
	                            </div><!-- .entry-meta -->
	                        </div><!-- .entry-container -->
	                    </article>
                	<?php endforeach ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>


    <?php }
endif;