<?php
/**
 * Popular Post section
 *
 * This is the template for the content of popular_post section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_popular_post_section' ) ) :
    /**
    * Add popular_post section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_popular_post_section() {
        $options = pet_business_pro_get_theme_options();
        // Check if popular_post is enabled on frontpage
        $popular_post_enable = apply_filters( 'pet_business_pro_section_status', true, 'popular_post_section_enable' );

        if ( true !== $popular_post_enable ) {
            return false;
        }
        // Get popular_post section details
        $section_details = array();
        $section_details = apply_filters( 'pet_business_pro_filter_popular_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_post section now.
        pet_business_pro_render_popular_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'pet_business_pro_get_popular_post_section_details' ) ) :
    /**
    * popular_post section details.
    *
    * @since Pet Business Pro 1.0.0
    * @param array $input popular_post section details.
    */
    function pet_business_pro_get_popular_post_section_details( $input ) {
        $options = pet_business_pro_get_theme_options();

        // Content type.
        $popular_post_content_type  = $options['popular_post_content_type'];
        $popular_post_count = ! empty( $options['popular_post_count'] ) ? $options['popular_post_count'] : 6;
        
        $content = array();
        switch ( $popular_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_post_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_post_content_category'] ) ? $options['popular_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['content']     = pet_business_pro_trim_content( 45 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                $page_post['id'] = get_the_ID();
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_post section content details.
add_filter( 'pet_business_pro_filter_popular_post_section_details', 'pet_business_pro_get_popular_post_section_details' );


if ( ! function_exists( 'pet_business_pro_render_popular_post_section' ) ) :
  /**
   * Start popular_post section
   *
   * @return string popular_post content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_popular_post_section( $content_details = array() ) {
        $options = pet_business_pro_get_theme_options();
        $popular_post_content_type  = $options['popular_post_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

    <?php if ( $options['home_layout'] == 'second-design' ): ?>

        <div id="blog-popular-posts" class="relative page-section">
            <div class="wrapper">

                <?php if ( ! empty( $options['popular_post_title'] ) ) : ?>

                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['popular_post_title'] ); ?></h2>
                    </div><!-- .section-header -->

                <?php endif; ?>

                <div class="section-content clear">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="popular-post-item">
                                <div class="blog-featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                                </div><!-- .blog-featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                     <?php 
                                     if ( 'page' !== $popular_post_content_type ) {
                                        $categories_list = get_the_category_list( esc_html__( ', ', 'pet-business-pro' ), '', $content['id'] );
                                                echo $categories_list; // WPCS: XSS OK.
                                            }
                                            ?>                              
                                        </span><!-- .cat-links -->

                                        <?php if ( ! empty( $content['title'] ) ) : ?>
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                        <?php endif; ?>

                                        <?php pet_business_pro_posted_on($content['id']); ?>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['content'] ); ?></p>
                                        </div>

                                        <?php if ( ! empty( $options['popular_post_button'] ) ) : ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['popular_post_button'] ); ?></a>
                                            </div><!-- .read-more -->
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .popular-post-item -->
                            </article>

                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #blog-popular-posts -->

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'third-design' ): ?>

        <div id="courses" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                <?php if ( ! empty( $options['popular_post_title'] ) ) : ?>
                    <h2 class="section-title"><?php echo esc_html( $options['popular_post_title'] ); ?></h2>
                <?php endif; ?>
                <?php if ( ! empty( $options['popular_post_description'] ) ) : ?>
                    <p class="section-subtitle"><?php echo esc_html( $options['popular_post_description'] ); ?></p>
                <?php endif; ?>
                </div>

                <!-- .supports col-1, col-2 and col-3 -->
                <div class="section-content clear col-3">

                     <?php foreach ( $content_details as $content ) : ?>

                    <article class="hentry">
                        <div class="courses-wrapper">
                        <?php if( !empty( $content['image'] ) ): ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="featured-image-link"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                            <div class="entry-container">

                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            <?php endif; ?>
                            <?php if( !empty( $content['content'] ) ): ?>
                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['content'] ); ?></p>
                                </div>
                            <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .courses-wrapper -->
                    </article>

                <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

    <?php endif; ?>
    <?php }
endif;