<?php
/**
 * Pricing section
 *
 * This is the template for the content of pricing section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_pricing_section' ) ) :
    /**
    * Add pricing section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_pricing_section() {
    	$options = pet_business_pro_get_theme_options();
        // Check if pricing is enabled on frontpage
        $pricing_enable = apply_filters( 'pet_business_pro_section_status', true, 'pricing_section_enable' );

        if ( ! $pricing_enable ) {
            return false;
        }

        // Render pricing section now.
        pet_business_pro_render_pricing_section();
    }
endif;

if ( ! function_exists( 'pet_business_pro_render_pricing_section' ) ) :
  /**
   * Start pricing section
   *
   * @return string pricing content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_pricing_section() {
       
        $options = pet_business_pro_get_theme_options();
        $image = ( ! empty( $options['pricing_image'] ) ) ? $options['pricing_image'] : '' ;
        if ( $options['pricing_count'] > 4 ) {
            $class = 4;
        } else {
            $class= $options['pricing_count'];
        }
        ?>

        <div id="pet_business_pro_pricing_section">

            <div id="pricing-table" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <!-- supports col-1, col-2, col-3, col-4 -->
                <div class="overlay"></div>
                <div class="wrapper">
                    <div class="section-header">
                        <?php if ( isset( $options['pricing_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['pricing_title'] ); ?></h2>
                        <?php endif; ?>

                        <?php if ( isset( $options['pricing_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo wp_kses_post( $options['pricing_sub_title'] ); ?></p>
                        <?php endif; ?>

                    </div><!-- .section-header -->

                    <!-- supports col-1, col-2 and col-3 -->
                    <div class="section-content col-<?php echo esc_attr( $class ); ?>">
                        <?php for ( $i=1; $i <= $options['pricing_count']; $i++ ) :  
                            ?>
                                <article>
                                    <div class="price-table-wrapper">
                                        <header class="entry-header">
                                            <?php if ( ! empty( $options['pricing_title_' . $i ] ) ) : ?>
                                                <h2 class="entry-title"><?php echo esc_html( $options['pricing_title_' . $i ] ); ?></h2>
                                            <?php endif; ?>

                                            <?php if ( ! empty( $options['pricing_price_' . $i ] ) ) : ?>
                                                <h3 class="price"><?php echo esc_html( $options['pricing_price_' . $i ] ); ?></h3>
                                            <?php endif; ?>
                                        </header>
                                        
                                        <ul>
                                            <?php 
                                            $price_lists = ! empty( $options['price_list_' . $i ] ) ? explode( '|', $options['price_list_' . $i ] ) : array();
                                            foreach ($price_lists as $price_list ) { 
                                                if ( isset( $price_list ) ) { 
                                                ?>
                                                    <li><?php echo esc_html( $price_list ); ?></li>
                                                <?php }  
                                            } ?>
                                        </ul>

                                        <?php if ( ! empty( $options['pricing_btn_' . $i ] ) ) : 
                                            $btn_url = ( ! empty( $options['pricing_btn_url_' . $i ] ) ) ? $options['pricing_btn_url_' . $i ] : '' ;

                                            ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-primary"><?php echo esc_html( $options['pricing_btn_' . $i ] ); ?></a>
                                            </div>
                                        <?php endif; ?>

                                    </div><!-- .price-table-wrapper -->
                                </article>
                            <?php 
                        endfor; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #pricing -->

            </div>

        <?php
    }
endif;