<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

$options = pet_business_pro_get_theme_options();


if ( ! function_exists( 'pet_business_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Pet Business Pro 1.0.0
	 */
	function pet_business_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'pet_business_pro_doctype', 'pet_business_pro_doctype', 10 );


if ( ! function_exists( 'pet_business_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'pet_business_pro_before_wp_head', 'pet_business_pro_head', 10 );

if ( ! function_exists( 'pet_business_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'pet-business-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'pet_business_pro_page_start_action', 'pet_business_pro_page_start', 10 );

if ( ! function_exists( 'pet_business_pro_topbar' ) ) :
	/**
	 * Top menu html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_topbar() {
		$options = pet_business_pro_get_theme_options();
		if ( ! $options['topbar_section_enable'] ) {
			return;
		}
		?>
		<?php if ( $options['home_layout'] == 'fourth-design' ): ?>
		<div id="top-bar" class="relative">
			<svg viewBox="0 0 284.929 284.929" class="dropdown-icon icon-up">
                <path d="M282.082,195.285L149.028,62.24c-1.901-1.903-4.088-2.856-6.562-2.856s-4.665,0.953-6.567,2.856L2.856,195.285C0.95,197.191,0,199.378,0,201.853c0,2.474,0.953,4.664,2.856,6.566l14.272,14.271c1.903,1.903,4.093,2.854,6.567,2.854c2.474,0,4.664-0.951,6.567-2.854l112.204-112.202l112.208,112.209c1.902,1.903,4.093,2.848,6.563,2.848c2.478,0,4.668-0.951,6.57-2.848l14.274-14.277c1.902-1.902,2.847-4.093,2.847-6.566C284.929,199.378,283.984,197.188,282.082,195.285z"></path>
            </svg>
            <svg viewBox="0 0 129 129" class="dropdown-icon icon-down">
                <path d="m121.3,34.6c-1.6-1.6-4.2-1.6-5.8,0l-51,51.1-51.1-51.1c-1.6-1.6-4.2-1.6-5.8,0-1.6,1.6-1.6,4.2 0,5.8l53.9,53.9c0.8,0.8 1.8,1.2 2.9,1.2 1,0 2.1-0.4 2.9-1.2l53.9-53.9c1.7-1.6 1.7-4.2 0.1-5.8z"></path>
            </svg>

			<div class="wrapper">
				<div class="col-2 clear">
					<div class="hentry">
						<ul class="contact-info clear">
						<?php if ( ! empty( $options['phone_no'] ) ): ?>
							<li>
								<?php 
								echo pet_business_pro_get_svg( array( 'icon' => 'phone' ) );
								echo esc_html( $options['phone_no'] );
								?>
							</li>
						<?php endif; ?>
						<?php if ( ! empty( $options['email_address'] ) ): ?>
							<li><?php 
								echo pet_business_pro_get_svg( array( 'icon' => 'mail' ) );
								echo esc_html( $options['email_address'] );
								?>
							</li>
						<?php endif; ?>
						</ul><!-- .contact-info -->
					</div><!-- .hentry -->

					
						<?php if( has_nav_menu('social') ): ?>
							<div class="hentry">
								<?php
								wp_nav_menu( 
									array(
										'theme_location' => 'social',
										'container' => 'div',
										'container_class' => 'secondary-menu',
										'menu_class' => 'social-icons',
										'echo' => true,
										'link_before' => '<span class="screen-reader-text">',
										'link_after' => '</span>',
										)
									);
									?><!-- .secondary-menu -->
								</div><!-- .hentry -->

							<?php endif; ?><!-- .secondary-menu -->
				</div><!-- .col-2 -->
			</div><!-- .wrapper -->
		</div>

	<?php endif; ?>
		<?php
	}
endif;
add_action( 'pet_business_pro_page_start_action', 'pet_business_pro_topbar', 10 );

if ( ! function_exists( 'pet_business_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'pet_business_pro_page_end_action', 'pet_business_pro_page_end', 10 );

if ( ! function_exists( 'pet_business_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_header_start() { ?>
		<header id="masthead" class="site-header" role="banner">
		<div class="background">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'pet_business_pro_header_action', 'pet_business_pro_header_start', 10 );

if ( ! function_exists( 'pet_business_pro_sidr_menu' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_sidr_menu() { ?>
		<a id="sidr-left-top-button" class="menu-button right menu-toggle" href="#sidr-left-top">
            <span class="menu-label"><?php esc_html_e( 'Menu', 'pet-business-pro' ); ?></span>
            <?php echo pet_business_pro_get_svg( array( 'icon' => 'menu' ) ); ?>
            <?php echo pet_business_pro_get_svg( array( 'icon' => 'close' ) ); ?>
        </a><!-- .sidr-left-top-button -->
		<?php
	}
endif;
add_action( 'pet_business_pro_header_action', 'pet_business_pro_sidr_menu', 15 );

if ( ! function_exists( 'pet_business_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_site_branding() {
		$options  = pet_business_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( pet_business_pro_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
			<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'pet_business_pro_header_action', 'pet_business_pro_site_branding', 20 );

if ( ! function_exists( 'pet_business_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_site_navigation() {
		$options = pet_business_pro_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<?php  
				$search = '';
				if ( $options['nav_search_enable'] ) :
					$search = '<li class="search-menu"><a href="#">';
					$search .= pet_business_pro_get_svg( array( 'icon' => 'search' ) );
					$search .= pet_business_pro_get_svg( array( 'icon' => 'close' ) );
					$search .= '</a><div id="search">';
					$search .= get_search_form( $echo = false );
                endif;

                if ( $options['home_layout'] == 'default-design' ):

				if ( $options['nav_btn'] ) :
					$search .= '<li class="adopt-pet"><a href="'. esc_url( $options['nav_btn_url'] ) .'">
                        '. pet_business_pro_get_svg( array( 'icon' => 'adapt' ) ) . esc_html( $options['nav_btn_txt'] ) .'</a>
                        </li>';
				endif;

				endif;

        		wp_nav_menu( array(
        			'theme_location' => 'primary',
        			'container' => false,
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'pet_business_pro_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
        		) );
        	?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'pet_business_pro_header_action', 'pet_business_pro_site_navigation', 30 );


if ( ! function_exists( 'pet_business_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_header_end() {
		?>
			</div><!-- .wrapper -->
			</div>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'pet_business_pro_header_action', 'pet_business_pro_header_end', 50 );

if ( ! function_exists( 'pet_business_pro_mobile_menu' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_mobile_menu() {
		?>
		<div id="sidr-left-top" class="mobile-menu sidr left">
		    <?php  
				$options = pet_business_pro_get_theme_options();
				$search = '';
				if ( $options['nav_search_enable'] ) :
					$search = '<li class="search-menu"><a href="#">';
					$search .= pet_business_pro_get_svg( array( 'icon' => 'search' ) );
					$search .= pet_business_pro_get_svg( array( 'icon' => 'close' ) );
					$search .= '</a><div id="search">';
					$search .= get_search_form( $echo = false );
	                $search .= '</div><!-- #search --></li>';
                endif;

                 if ( $options['home_layout'] == 'default-design' ):

				if ( $options['nav_btn'] ) :
					$search .= '<li class="adopt-pet"><a href="'. esc_url( $options['nav_btn_url'] ) .'">
                        '. pet_business_pro_get_svg( array( 'icon' => 'adapt' ) ) . esc_html( $options['nav_btn_txt'] ) .'</a>
                        </li>';
				endif;

				endif;

        		wp_nav_menu( array(
        			'theme_location' => 'primary',
        			'container' => false,
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'pet_business_pro_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
        		) );
        	?>
		</div><!-- #sidr-left-top -->
		<?php
	}
endif;

add_action( 'pet_business_pro_mobile_menu', 'pet_business_pro_mobile_menu', 10 );

if ( ! function_exists( 'pet_business_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'pet_business_pro_content_start_action', 'pet_business_pro_content_start', 10 );

if ( ! function_exists( 'pet_business_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Pet Business Pro 1.0.0
	 */
	function pet_business_pro_add_breadcrumb() {
		$options = pet_business_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( pet_business_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >
			<div class="wrapper">';
				/**
				 * pet_business_pro_simple_breadcrumb hook
				 *
				 * @hooked pet_business_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'pet_business_pro_simple_breadcrumb' );
		echo '</div>
			</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'pet_business_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_header_image() {
		$options = pet_business_pro_get_theme_options();
		if ( pet_business_pro_is_frontpage() )
			return;

		$header_image = get_header_image();

		if ( is_singular() && has_header_image() ) :
			$header_image = ( has_post_thumbnail() ) ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;

	?>

		<div id="page-site-header" class="relative <?php echo ( has_header_image() ) ? 'has-post-thumbnail' : 'no-post-thumbnail' ; ?>" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <?php if( has_header_image() ) echo '<div class="overlay"></div>'; ?>
            <div class="wrapper">
            	<div id="page-header-wrapper">
	                <header class="page-header">
	                   <?php pet_business_pro_custom_header_banner_title(); ?>
	                </header>
                	<?php pet_business_pro_add_breadcrumb(); ?>
            	</div>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->

		<?php
	}
endif;
add_action( 'pet_business_pro_header_image_action', 'pet_business_pro_header_image', 10 );

if ( ! function_exists( 'pet_business_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'pet_business_pro_content_end_action', 'pet_business_pro_content_end', 10 );

if ( ! function_exists( 'pet_business_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'pet_business_pro_footer', 'pet_business_pro_footer_start', 10 );

if ( ! function_exists( 'pet_business_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_footer_site_info() {
		$options = pet_business_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_html( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 

		$class = ( has_nav_menu( 'social' ) && $options['footer_social_visible'] ) ? 2 : 1 ;
		?>

		<div class="site-info col-<?php echo esc_attr( $class ); ?>">
                <div class="wrapper">
                    <span class="copyright">
                    	<?php 
                    	echo pet_business_pro_santize_allow_tag( $copyright_text ); 
                    	if ( function_exists( 'the_privacy_policy_link' ) ) {
						    the_privacy_policy_link( ' | ' );
						}
                    	?>
                    	</span>
                    <?php if ( has_nav_menu( 'social' ) && $options['footer_social_visible'] ) : ?>
	                        <?php  
			            		wp_nav_menu( array(
			            			'theme_location' => 'social',
			            			'container' => 'div',
			            			'container' => 'social-icons',
			            			'menu_class' => 'menu',
			            			'echo' => true,
			            			'fallback_cb' => false,
			            			'depth' => 1,
			            			'link_before' => '<span class="screen-reader-text">',
									'link_after' => '</span>',
			            		) );
			            	?>
	                <?php endif; ?>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->


		<?php
	}
endif;
add_action( 'pet_business_pro_footer', 'pet_business_pro_footer_site_info', 40 );

if ( ! function_exists( 'pet_business_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_footer_scroll_to_top() {
		$options  = pet_business_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo pet_business_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'pet_business_pro_footer', 'pet_business_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'pet_business_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_loader() {
		$options = pet_business_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo pet_business_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'pet_business_pro_before_header', 'pet_business_pro_loader', 10 );

if ( ! function_exists( 'pet_business_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Pet Business Pro 1.0.0
	 *
	 */
	function pet_business_pro_infinite_loader_spinner() { 
		global $post;
		$options = pet_business_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . pet_business_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'pet_business_pro_infinite_loader_spinner_action', 'pet_business_pro_infinite_loader_spinner', 10 );
